@@ -17,7 +17,7 @@ fbGetBusinessUserAdAccounts <- function(business_users_id = NULL,
     }
   }
   
-  if ( class(access_token) == "fb_access_token" ) {
+  if ( inherits(access_token, "fb_access_token") ) {
     
     access_token <- access_token$access_token
     
